@@ -186,18 +186,31 @@ class PowerBusDaemon(object):
 		if not self.is_root:
 			raise PermissionError()
 
-		os.umask(0o700)
-		# TODO: if dir exists -- I don't think this will enforce mode. Also check owner.
-		os.makedirs("/run/funtoo", mode=0o700, exist_ok=True)
+		if not os.path.isdir("/run"):
+			raise FileNotFoundError("/run not found and required by funtoo-powerbus.")
+		os.umask(0o022)
+		if not os.path.exists("/run/funtoo"):
+			os.mkdir("/run/funtoo", 0o700)
 
-		put_file("/run/funtoo/powerbus.pid", str(os.getpid()))
+		# Give us exclusive access to this directory while we set it up:
+		os.chown("/run/funtoo", 0, 0)
+		os.chmod("/run/funtoo", 0o700)
+		try:
+			put_file("/run/funtoo/powerbus.pid", str(os.getpid()))
+		except PermissionError:
+			raise PermissionError("Unable to write PID file at /runt/funtoo/powerbus.pid.")
 
+		os.umask(0o000)
 		# ZMQ Setup:
 		self.bind_addr = powerbus.zmq_bus.BUS_PATH
 		self.ctx = zmq.asyncio.Context()
 		self.identities = {}
 		self.server: zmq.asyncio.Socket = self.ctx.socket(zmq.ROUTER)
 		self.server.bind(self.bind_addr)
+
+		# Now that all files (including powerbus-socket) are in place -- relax permissions.
+		os.chmod("/run/funtoo", 0o755)
+		os.umask(0o022)
 		logging.debug(f"Listening for new client connections at {self.bind_addr}")
 
 		# PowerBus Internals Setup:
